import { GraphQLAPIProvider, StackManagerProvider, TransformerContextOutputProvider, TransformerContextProvider, TransformerDataSourceManagerProvider, AppSyncAuthConfiguration, VpcConfig, RDSLayerMapping, SynthParameters } from '@aws-amplify/graphql-transformer-interfaces';
import type { AssetProvider, NestedStackProvider, TransformParameterProvider, TransformParameters } from '@aws-amplify/graphql-transformer-interfaces';
import { TransformerContextMetadataProvider } from '@aws-amplify/graphql-transformer-interfaces/src/transformer-context/transformer-context-provider';
import { DocumentNode } from 'graphql';
import { Construct } from 'constructs';
import { DatasourceType } from '../config/project-config';
import { ResolverConfig } from '../config/transformer-config';
import { RDSConnectionSecrets } from '../types';
import { TransformerContextProviderRegistry } from './provider-registry';
import { ResolverManager } from './resolver';
import { TransformerResourceHelper } from './resource-helper';
export { TransformerResolver } from './resolver';
export { StackManager } from './stack-manager';
export declare class TransformerContextMetadata implements TransformerContextMetadataProvider {
    private metadata;
    get<T>(key: string): T | undefined;
    set<T>(key: string, val: T): void;
    has(key: string): boolean;
}
export declare class TransformerContext implements TransformerContextProvider {
    readonly synthParameters: SynthParameters;
    readonly inputDocument: DocumentNode;
    readonly output: TransformerContextOutputProvider;
    readonly resolvers: ResolverManager;
    readonly dataSources: TransformerDataSourceManagerProvider;
    readonly providerRegistry: TransformerContextProviderRegistry;
    readonly stackManager: StackManagerProvider;
    readonly resourceHelper: TransformerResourceHelper;
    readonly transformParameters: TransformParameters;
    _api?: GraphQLAPIProvider;
    readonly authConfig: AppSyncAuthConfiguration;
    private resolverConfig;
    readonly modelToDatasourceMap: Map<string, DatasourceType>;
    readonly datasourceSecretParameterLocations: Map<string, RDSConnectionSecrets>;
    readonly sqlLambdaVpcConfig?: VpcConfig;
    readonly rdsLayerMapping?: RDSLayerMapping;
    metadata: TransformerContextMetadata;
    constructor(scope: Construct, nestedStackProvider: NestedStackProvider, parameterProvider: TransformParameterProvider | undefined, assetProvider: AssetProvider, synthParameters: SynthParameters, inputDocument: DocumentNode, modelToDatasourceMap: Map<string, DatasourceType>, stackMapping: Record<string, string>, authConfig: AppSyncAuthConfiguration, transformParameters: TransformParameters, resolverConfig?: ResolverConfig, datasourceSecretParameterLocations?: Map<string, RDSConnectionSecrets>, sqlLambdaVpcConfig?: VpcConfig, rdsLayerMapping?: RDSLayerMapping);
    get api(): GraphQLAPIProvider;
    getResolverConfig: <ResolverConfig_1>() => ResolverConfig_1 | undefined;
    isProjectUsingDataStore(): boolean;
}
//# sourceMappingURL=index.d.ts.map